<?php

if (!defined('ABSPATH')) exit; // Exit if accessed directly


class Blog extends \Elementor\Widget_Base{

  public function get_name(){
    return 'blog_slope';
  }

  public function get_title(){
    return __( 'Blog', 'slope' );
  }

  public function get_icon(){
    return 'fas fa-bullhorn';
  }

  public function get_categories(){
    return ['gfxpartner'];
  }

  protected function register_controls(){

    // post options - start

    $this->start_controls_section(
      'blog_section',
      [
          'label' => __( 'Post Options', 'slope' ),
          'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
      ]
    );

    $this->add_control(
			'blog_layout',
			[
				'label' => __( 'Layout', 'slope' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'grid',
				'options' => [
					'grid'  => __( 'Grid', 'slope' ),
					'list' => __( 'List', 'slope' ),
          'grid-1'  => __( 'Grid with excerpt', 'slope' ),
					'list-1' => __( 'List with excerpt', 'slope' ),
				],
			]
		);

    $this->add_control(
      'slope_posts_number',
      [
        'label' => __( 'Posts per page', 'slope' ),
        'type'  => \Elementor\Controls_Manager::NUMBER,
        'min'			=> -1,
        'default' => 2
      ]
    );

    $this->add_control(
    'slope_posts_order',
    [
      'label' => __( 'Order posts', 'slope' ),
      'type' => \Elementor\Controls_Manager::SELECT,
      'options' => [
        'DESC' => 'descending',
        'ASC' => 'ascending',
      ],
      'default' => 'DESC',
    ]
    );

    $this->add_control(
    'slope_posts_sort',
    [
      'label' => __( 'Sorting posts by', 'slope' ),
      'type' => \Elementor\Controls_Manager::SELECT,
      'options' => [
        'date' => 'date',
        'modified' => 'last modified date',
        'rand' => 'Random',
        'title' => 'title',
        'comment_count' => 'number of comments',
      ],
      'default' => 'date',
    ]
    );

    $this->add_control(
      'show_pagination',
      [
        'label' => __( 'Show pagination', 'slope' ),
        'type' => \Elementor\Controls_Manager::SWITCHER,
        'label_on' => __( 'Show', 'slope' ),
        'label_off' => __( 'Hide', 'slope' ),
        'return_value' => 'yes',
        'default' => 'yes',
      ]
    );

    $this->end_controls_section();

    // post options - end

    // categories - start

    $this->start_controls_section(
      'blog_category_section',
      [
          'label' => __( 'Category', 'slope' ),
          'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
      ]
    );

    $this->add_control(
      'show_isotope',
      [
        'label' => __( 'Show category filter', 'slope' ),
        'type' => \Elementor\Controls_Manager::SWITCHER,
        'label_on' => __( 'Show', 'slope' ),
        'label_off' => __( 'Hide', 'slope' ),
        'return_value' => 'yes',
        'default' => 'yes',
      ]
    );

    $this->add_control(
      'show_all_categories',
      [
        'label' => __( 'Show all categories', 'slope' ),
        'type' => \Elementor\Controls_Manager::SWITCHER,
        'label_on' => __( 'Show', 'slope' ),
        'label_off' => __( 'Hide', 'slope' ),
        'return_value' => 'yes',
        'condition' => [
          'show_isotope' => 'yes'
        ],
        'default' => 'yes',
      ]
    );

    $repeater = new \Elementor\Repeater();

    $repeater->add_control(
      'category_name',
      [
          'label' => __('Category name', 'slope'),
          'label_block' => true,
          'type' => \Elementor\Controls_Manager::TEXT,
          'default' => ''
      ]
    );

    $repeater->add_control(
      'category_slug',
      [
          'label' => __('Category slug', 'slope'),
          'label_block' => true,
          'type' => \Elementor\Controls_Manager::TEXT,
          'default' => ''
      ]
    );

    $this->add_control(
      'category_slider',
      [
        'label' => __( 'Categories', 'slope' ),
        'type' => \Elementor\Controls_Manager::REPEATER,
        'fields' => $repeater->get_controls(),
        'default' => [
          [
            'category_name' => '',
            'category_slug' => ''
          ],
          
        ],
        'conditions' => [
          'relation'  => 'and',
          'terms'     => [
            [
              'name'  => 'show_isotope',
              'operator'  => '==',
              'value' => 'yes'
            ],
            [
              'name'  => 'show_all_categories',
              'operator'  => '!=',
              'value' => 'yes'
            ]
          ]
        ],
        'title_field' => __ ( 'Category','slope' ),
      ]
    );
     
    $this->end_controls_section();

    // categories - end

    // title - start

    $this->start_controls_section(
      'blog_title_style_section',
      [
        'label' => __('Title', 'slope'),
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );

    $this->add_group_control(
      \Elementor\Group_Control_Typography::get_type(),
      [
          'name' => 'blog_title_format',
          'label' => __('Typography', 'slope'),
          'selector' => '{{WRAPPER}} .blog-list-single--content h2',
      ]
    );

    $this->add_control(
      'blog_title_color',
      [
        'label' => __('Color', 'slope'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .blog-list-single--content h2' => 'color : {{VALUE}}',
        ],
      ]
    );

    $this->end_controls_section();

    // title - end

    // date and category - start

    $this->start_controls_section(
      'blog_date_category_section',
      [
        'label' => __('Date and Category', 'slope'),
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );

    $this->add_group_control(
      \Elementor\Group_Control_Typography::get_type(),
      [
          'name' => 'blog_cat_date_format',
          'label' => __('Typography', 'slope'),
          'selector' => '{{WRAPPER}} .blog-list-single--content div a,
          {{WRAPPER}} .blog-list-single--content div h6,
          {{WRAPPER}} .blog-list-single--content div span',
      ]
    );

    $this->add_control(
      'blog_cat_date_color',
      [
        'label' => __('Color', 'slope'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .blog-list-single--content div a,
          {{WRAPPER}} .blog-list-single--content div h6,
          {{WRAPPER}} .blog-list-single--content div span' => 'color : {{VALUE}}',
        ],
      ]
    );

    $this->end_controls_section();

    // date and category - end

    // hover - start

    $this->start_controls_section(
      'blog_hover_section',
      [
        'label' => __('Hover', 'slope'),
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );

    $this->add_control(
      'blog_hover_background_color',
      [
        'label' => __('Overlay color', 'slope'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .blog-list-single--thumbnail .hover' => 'background-color : {{VALUE}}',
        ],
      ]
    );

    $this->add_control(
      'blog_hover_icon_background_color',
      [
        'label' => __('Overlay circl color', 'slope'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .blog-list-single--thumbnail .hover .circle' => 'background-color : {{VALUE}}',
        ],
      ]
    );

    $this->add_control(
      'blog_hover_icon_color',
      [
        'label' => __('Overlay icon color', 'slope'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .blog-list-single--thumbnail .hover i' => 'color : {{VALUE}}',
          '{{WRAPPER}} .blog-list-single--thumbnail .hover svg' => 'fill : {{VALUE}}',
        ],
      ]
    );

    $this->end_controls_section();

    // hover - end
  
  }
  

  protected function render(){
    $settings = $this->get_settings_for_display();
    $id = $this->get_id();

    global $wp_query; global $post;

    $paged = (get_query_var('paged')) ? get_query_var('paged') : 1; 

    $args = array(
      'posts_per_page' => esc_attr($settings['slope_posts_number']),
      'orderby'     => esc_attr($settings['slope_posts_sort']),
      'order'       => esc_attr($settings['slope_posts_order']),      
      'post_type' => esc_attr('post'),
      'paged' => $paged,
      'post_status'    => 'publish'
    );
      
    $query = new \WP_Query( $args );
    

  ?>
    <div class="blog-list">
        <div class="container">

            <?php if ($settings['show_isotope'] == 'yes'): ?>
            <div class="row">
                <div class="col">
                  <ul class="filter filter-list filter-<?php echo esc_attr($id); ?>">
                      <li><a href="#" data-filter="*" class="selected"><?php echo esc_html__('All', 'slope') ?></a></li>
                      <?php
                          if ($settings['show_all_categories'] == 'yes') { 
                            $terms = get_terms("category"); // get all categories, but you can use any taxonomy
                            $count = count($terms); //How many are they?
                            if ( $count > 0 ){  //If there are more than 0 terms
                                foreach ( $terms as $term ) {  //for each term:
                                    echo "<li><a href='#' data-filter='.".esc_attr($term->slug)."'>" . esc_html($term->name) . "</a></li>\n";
                                    //create a list item with the current term slug for sorting, and name for label
                                }
                            } 
                          } else {
                            foreach($settings['category_slider'] as $item) {
                              echo "<li><a href='#' data-filter='.".esc_attr($item['category_slug'])."'>" .esc_html($item['category_name']). "</a></li>\n";
                            }
                          } 
                      ?>
                  </ul>
                  <div class="filter filter-select filter-<?php echo esc_attr($id); ?>">
                    <select>
                      <option value="*"><?php echo esc_html__('All', 'slope') ?></option>
                      <?php
                          if ($settings['show_all_categories'] == 'yes') { 
                            $terms = get_terms("category"); // get all categories, but you can use any taxonomy
                            $count = count($terms); //How many are they?
                            if ( $count > 0 ){  //If there are more than 0 terms
                                foreach ( $terms as $term ) {  //for each term:
                                    echo "<option value='.".esc_attr($term->slug)."'>" . esc_html($term->name) . "</option>\n";
                                    //create a list item with the current term slug for sorting, and name for label
                                }
                            } 
                          } else {
                            foreach($settings['category_slider'] as $item) {
                              echo "<option value='.".esc_attr($item['category_slug'])."'>" .esc_html($item['category_name']). "</option>\n";
                            }
                          } 
                      ?>
                    </select>
                  </div>
                </div>
            </div>
            <?php endif; ?>
            
            <!-- blog list container - start -->
            <div 
            class="row blog-list-container blog-list-container-<?php echo esc_attr($id); ?> blog-list-container-<?php echo esc_html( $settings['blog_layout'] ); ?>" 
            id="<?php echo esc_attr($id); ?>"
            >
            <?php 
            
              if ($query->have_posts()): 
                while ($query->have_posts()): 
                  $query->the_post();


                  $termsString = ''; //initialize the string that will contain the terms
                  if ( $settings['show_isotope'] == 'yes' ) {
                    $termsArray = get_the_terms( get_the_ID(), 'category' );  //Get the terms for this particular item
                    if ($termsArray) {
                      foreach ( $termsArray as $term ) { // for each term 
                          $termsString .= $term->slug.' '; //create a string that has all the slugs 
                      }
                    }
                  }
        
                  get_template_part('inc/template/part', 'post', array(
                    'id' => $id,
                    'blog_layout' => $settings['blog_layout'],
                    'termsString' => $termsString
                  ));

                endwhile; 
                  
                wp_reset_postdata(); 

              endif; 

              ?>
            </div>
            <!-- blog list container - end -->

            <!-- blog pagination - start -->
            <?php if ($settings['show_pagination'] == 'yes'): ?>
            <div class="row">
              <div class="col">  
                <?php slope_widget_link_pages($query, "", ""); ?>
              </div>
            </div>
            <?php endif; ?>
            <!-- blog pagination - end -->

        </div>
    </div>
  <?php 
    if ( $settings['show_isotope'] == 'yes' ) {
      slope_render_isotope_script($id); 
    }
  }
}

