<?php

if (!defined('ABSPATH')) exit; // Exit if accessed directly


class Button extends \Elementor\Widget_Base{

  public function get_name(){
    return 'button_slope';
  }

  public function get_title(){
    return __( 'Button', 'slope' );
  }

  public function get_icon(){
    return 'fas fa-keyboard';
  }

  public function get_categories(){
    return ['gfxpartner'];
  }

  protected function register_controls(){

    // button content -  start

    $this->start_controls_section(
      'button_content',
      [
        'label' => __('Content', 'slope'),
        'tab' => \Elementor\Controls_Manager::TAB_CONTENT
      ]
    );


    $this->add_control(
        'button_text',
        [
        'label' => __('Text', 'slope'),
        'type' => \Elementor\Controls_Manager::TEXT,
        'default' => ''
        ]
    );

    $this->add_control(
        'button_link',
        [
            'label' => __('Link', 'slope'),
            'type' => \Elementor\Controls_Manager::URL,
        
        ]
    );

    $this->end_controls_section();

    // button content -  end

    // button style -  start

    $this->start_controls_section(
        'button_custom_style',
        [
          'label' => __('Style', 'slope'),
          'tab' => \Elementor\Controls_Manager::TAB_STYLE
        ]
    );

    $this->add_group_control(
        \Elementor\Group_Control_Typography::get_type(),
        [
            'name' => 'button_text',
            'label' => __('Text', 'slope'),
            'selector' => '{{WRAPPER}} .button',
        ]
    );

    $this->add_responsive_control('button_align',
      [
          'label'         => __( 'Alignment', 'slope' ),
          'type'          => \Elementor\Controls_Manager::CHOOSE,
          'options'       => [
              'left'      => [
                  'title'=> __( 'Left', 'slope' ),
                  'icon' => 'fa fa-align-left',
              ],
              'center'    => [
                  'title'=> __( 'Center', 'slope' ),
                  'icon' => 'fa fa-align-center',
              ],
              'right'     => [
                  'title'=> __( 'Right', 'slope' ),
                  'icon' => 'fa fa-align-right',
              ],
          ],
          'default'       => 'center',
          'selectors'     => [
              '{{WRAPPER}}' => 'text-align: {{VALUE}};',
          ],
      ]
    );

    $this->start_controls_tabs( 'button_tabs' );
    
    $this->start_controls_tab(
        'button_normal',
        [
            'label' => __( 'Normal', 'slope' ),
        ]
    );

    $this->add_control(
        'button_text_color',
        [
          'label' => __('Text color', 'slope'),
          'type' => \Elementor\Controls_Manager::COLOR,
          'selectors' => [
            '{{WRAPPER}} .button' => 'color : {{VALUE}}'
          ]
          
        ]
    );

    $this->add_control(
      'button_bg_color',
      [
        'label' => __('Background color', 'slope'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .button::before' => 'background-color : {{VALUE}}'
        ]
        
      ]
    );


    $this->end_controls_tab();

    $this->start_controls_tab(
        'button_hover',
        [
            'label' => __( 'Hover', 'slope' ),
        ]
    );

    $this->add_control(
        'button_text_color_hover',
        [
          'label' => __('Text hover color', 'slope'),
          'type' => \Elementor\Controls_Manager::COLOR,
          'selectors' => [
            '{{WRAPPER}} .button:hover' => 'color : {{VALUE}}'
          ]
          
        ]
    );

    $this->add_control(
      'button_bg_color_hover',
      [
        'label' => __('Background color', 'slope'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .button::after' => 'background-color : {{VALUE}}'
        ]
        
      ]
    );

    $this->end_controls_tab();

    $this->end_controls_tabs();  

    $this->end_controls_section();

    // button style -  end
  
  }
  

  protected function render(){
    $settings = $this->get_settings_for_display();

    $target = $settings['button_link']['is_external'] ? ' target="_blank"' : '';
    $nofollow = $settings['button_link']['nofollow'] ? ' rel="nofollow"' : '';
    $url = !empty( $settings['button_link']['url'] ) ? ' href='.esc_url( $settings['button_link']['url'] ) : '';
  ?>
    <a
    class="button"
    <?php echo esc_attr($url); ?>
    <?php echo esc_attr($target); ?>
    <?php echo esc_attr($nofollow); ?>
    >
      <?php echo esc_html($settings['button_text']); ?>
    </a>
    <?php
  }
}
