<?php

if (!defined('ABSPATH')) exit; // Exit if accessed directly


class ClientSlider extends \Elementor\Widget_Base{

  public function get_name(){
    return 'client_slope';
  }

  public function get_title(){
    return __( 'Client Slider', 'slope' );
  }

  public function get_icon(){
    return 'fas fa-user-friends';
  }

  public function get_categories(){
    return ['gfxpartner'];
  }

  protected function register_controls(){

    // slides - start

    $this->start_controls_section(
      'client_slider_content',
      [
        'label' => __('Slides', 'slope'),
        'tab' => \Elementor\Controls_Manager::TAB_CONTENT
      ]
    );

    $repeater = new \Elementor\Repeater();

    $repeater->add_control(
        'client_image',
        [
            'label' => __( 'Choose Image', 'slope' ),
            'type' => \Elementor\Controls_Manager::MEDIA,
            'default' => [
                'url' => \Elementor\Utils::get_placeholder_image_src(),
            ],
        ]
    );

    $repeater->add_control(
        'client_link',
        [
            'label' => __( 'Link', 'slope' ),
            'type' => \Elementor\Controls_Manager::URL,
            'placeholder' => __( 'https://your-link.com', 'slope' ),
            'show_external' => true,
            'default' => [
                'url' => '',
                'is_external' => true,
                'nofollow' => true,
            ],
        ]
    );

    $this->add_control(
      'client_slider_repeater',
      [
        'label' => __( 'Client slides', 'slope' ),
        'type' => \Elementor\Controls_Manager::REPEATER,
        'fields' => $repeater->get_controls(),
        'default' => [
          [
            'client_image' => '',
            'client_link' => ''
          ],
        ],
        'title_field' => __ ( 'Client','slope' ),
      ]
    );

    $this->end_controls_section();

    // slides - end

    // slider options - start

    $this->start_controls_section(
      'client_slider_options_section',
      [
        'label' => __('Slider options', 'slope'),
        'tab' => \Elementor\Controls_Manager::TAB_CONTENT
      ]
    );
  
    $this->add_control(
      'client_slider_autoplay',
      [
        'label' => __( 'Slider autoplay', 'slope' ),
        'type' => \Elementor\Controls_Manager::SWITCHER,
        'label_on' => __( 'yes', 'slope' ),
        'label_off' => __( 'no', 'slope' ),
        'return_value' => 'yes',
        'default' => 'yes',
      ]
    );

    $this->add_control(
      'client_slider_autoplay_delay',
      [
        'label' => __( 'Delay', 'slope' ),
        'description' => __('1000 represents 1 second', 'slope'),
        'type' => \Elementor\Controls_Manager::NUMBER,
        'min' => 0,
        'max' => 60000,
        'step' => 500,
        'default' => 2000
      ]
    );

    $this->add_control(
      'client_slider_speed',
      [
        'label' => __( 'Speed', 'slope' ),
        'description' => __('1000 represents 1 second', 'slope'),
        'type' => \Elementor\Controls_Manager::NUMBER,
        'min' => 0,
        'max' => 60000,
        'step' => 500,
        'default' => 2000
      ]
    );

    $this->end_controls_section();

    // slider options - end
  
  }
  

  protected function render(){
    $settings = $this->get_settings_for_display();
    $id = $this->get_id();
    $options = [
      'speed' =>  $settings['client_slider_speed'],
      'slidesPerView' => 4,
      'spaceBetween' => 0,
      'breakpoints' => [
        '991.98' => [ 'slidesPerView' => 4 ],
        '768' => [ 'slidesPerView' => 3 ],
        '500' => [ 'slidesPerView' => 2 ],
        '0' => [ 'slidesPerView' => 1 ]
      ]
    ];
    if ( $settings['client_slider_autoplay'] == 'yes' ) {
      $delay_arr = ['autoplay' => [
        'delay' => $settings['client_slider_autoplay_delay']
      ]];
      $options = array_merge($options, $delay_arr);
    }
    ?>
    <div class="client-slider">
      <div class="swiper-container slider-<?php echo esc_attr($id); ?>">
        <div class="swiper-wrapper">
          <?php foreach ($settings['client_slider_repeater'] as $item):
            $target = $item['client_link']['is_external'] ? ' target="_blank"' : '';
            $nofollow = $item['client_link']['nofollow'] ? ' rel="nofollow"' : '';     
            ?>
            <div class="swiper-slide client-slide">
                <?php if ($item['client_link']['url']): ?>
                <a href="<?php echo esc_url($item['client_link']['url']); ?>" class="client-image" <?php echo esc_attr($target); ?> <?php echo esc_attr($nofollow); ?>>
                <?php endif; ?>
                    <?php echo \Elementor\Group_Control_Image_Size::get_attachment_image_html( $item, 'thumbnail', 'client_image' ); ?>
                <?php if ($item['client_link']['url']): ?>
                </a>
                <?php endif; ?>
            </div>
          <?php endforeach; ?>
        </div>
      </div>
    </div>
    <?php slope_render_script($id, $options, false); ?>
    <?php
  }

  protected function _content_template(){
    
  ?>
    <div class="client-slider">
      <div class="swiper-container slider-{{{id}}}">
        <div class="swiper-wrapper">
          <# for (let i = 0; i < settings.client_slider_repeater.length; i++) {
              var image = {
                id: settings.client_slider_repeater[i].client_image.id,
                url: settings.client_slider_repeater[i].client_image.url,
                size: settings.thumbnail_size,
                dimension: settings.thumbnail_custom_dimension,
                model: view.getEditModel()
              };
              var image_url = elementor.imagesManager.getImageUrl( image );  
          #>
            <div class="swiper-slide client-slide">
                <a href="#" class="client-image">
                    <img src="{{{image_url}}}" alt="image">
                </a>
            </div>
          <# } #>
        </div>
      </div>
    </div>

  <?php
  }
}
