<?php

if (!defined('ABSPATH')) exit; // Exit if accessed directly


class ContactForm7 extends \Elementor\Widget_Base {

	public function get_name() {
		return 'contact_form_slope';
	}

	public function get_title() {
		return __( 'Contact From 7', 'slope' );
	}

	public function get_icon() {
		return 'fas fa-mail-bulk';
	}

	public function get_categories() {
		return [ 'gfxpartner' ];
	}

	protected function register_controls() {
			
	//start of a control box
	$this->start_controls_section(
		'cf7_content',
		[
			'label' => esc_html__( 'Contact Form 7', 'slope' ), 
		]
	);

	$repeater = new \Elementor\Repeater();

	$repeater->add_control(
        'cf7_heading',
        [
        'label' => __('Form heading', 'slope'),
        'type' => \Elementor\Controls_Manager::TEXT,
        'default' => ''
        ]
    );

	$repeater->add_control(
		'cf7',
		[
			'label' => esc_html__( 'Select contact corm', 'slope' ),
			'description' => esc_html__('Contact form 7 must be installed for this widget to work','slope'),
			'type' => \Elementor\Controls_Manager::SELECT2,
			'multiple' => false,
			'options' => $this->get_contact_form_7_forms(),
		]
	);

	$this->add_control(
        'contact_form_repeater',
        [
          'label' => __( 'Forms', 'slope' ),
          'type' => \Elementor\Controls_Manager::REPEATER,
          'fields' => $repeater->get_controls(),
          'default' => [
            [
              'cf7' => '',
            ],
          ],
          'title_field' => __( 'Form','slope' ),
        ]
    );

	$this->end_controls_section();

	// button style -  start

    $this->start_controls_section(
        'cf_button_custom_style',
        [
          'label' => __('Style', 'slope'),
          'tab' => \Elementor\Controls_Manager::TAB_STYLE
        ]
    );

    $this->add_responsive_control('cf_button_align',
      [
          'label'         => __( 'Alignment', 'slope' ),
          'type'          => \Elementor\Controls_Manager::CHOOSE,
          'options'       => [
              'left'      => [
                  'title'=> __( 'Left', 'slope' ),
                  'icon' => 'fa fa-align-left',
              ],
              'center'    => [
                  'title'=> __( 'Center', 'slope' ),
                  'icon' => 'fa fa-align-center',
              ],
              'right'     => [
                  'title'=> __( 'Right', 'slope' ),
                  'icon' => 'fa fa-align-right',
              ],
          ],
          'default'       => 'left',
          'selectors'     => [
              '{{WRAPPER}} .submit-contact' => 'text-align: {{VALUE}};',
          ],
      ]
    );

    $this->start_controls_tabs( 'cf_button_tabs' );
    
    $this->start_controls_tab(
        'cf_button_normal',
        [
            'label' => __( 'Normal', 'slope' ),
        ]
    );

    $this->add_control(
        'cf_button_text_color',
        [
          'label' => __('Text color', 'slope'),
          'type' => \Elementor\Controls_Manager::COLOR,
          'selectors' => [
            '{{WRAPPER}} .button' => 'color : {{VALUE}}',
			'{{WRAPPER}} .submit-contact input' => 'color: {{VALUE}}'
          ]
          
        ]
    );

    $this->add_control(
      'cf_button_bg_color',
      [
        'label' => __('Background color', 'slope'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .button::before' => 'background-color : {{VALUE}}',
		  '{{WRAPPER}} .submit-contact input' => 'background-color : {{VALUE}}',
		  '{{WRAPPER}} .submit-contact input::before' => 'background-color : {{VALUE}}'
        ]
        
      ]
    );


    $this->end_controls_tab();

    $this->start_controls_tab(
        'cf_button_hover',
        [
            'label' => __( 'Hover', 'slope' ),
        ]
    );

    $this->add_control(
        'cf_button_text_color_hover',
        [
          'label' => __('Text hover color', 'slope'),
          'type' => \Elementor\Controls_Manager::COLOR,
          'selectors' => [
            '{{WRAPPER}} .button:hover' => 'color : {{VALUE}}',
			'{{WRAPPER}} .submit-contact input:hover' => 'color : {{VALUE}}'
          ]
          
        ]
    );

    $this->add_control(
      'cf_button_bg_color_hover',
      [
        'label' => __('Background color', 'slope'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .button::after' => 'background-color : {{VALUE}}',
		  '{{WRAPPER}} .submit-contact input:hover' => 'background-color : {{VALUE}}',
		  '{{WRAPPER}} .submit-contact input::after' => 'background-color : {{VALUE}}'
        ]
        
      ]
    );

    $this->end_controls_tab();

    $this->end_controls_tabs();  

    $this->end_controls_section();

    // button style -  end

	}


	protected function render() {			
		$settings = $this->get_settings();
		$id = $this->get_id();
		
		?>

		<div class="contact-form-wrapper">
		
			<div class="nav-pills-wrapper">
				<ul class="nav nav-pills contact-form-tab" role="tablist">
				<?php $incre_id = 1; foreach ($settings['contact_form_repeater'] as $item): ?>
					<li class="nav-item">
						<a class="nav-link <?php echo esc_attr($incre_id == 1 ? 'active': ''); ?>" 
						id="slope-cf7-id-<?php echo esc_attr($id.strval($incre_id)); ?>-tab" 
						data-toggle="pill" href="#slope-cf7-id-<?php echo esc_attr($id.strval($incre_id)); ?>" role="tab" 
						aria-controls="slope-cf7-id-<?php echo esc_attr($id.strval($incre_id)); ?>" aria-selected="true">
						<span>
							<?php echo esc_html($item['cf7_heading']); ?>
						</span>
					</a>
					</li>
					
				<?php $incre_id++; endforeach; ?>
				</ul>
			</div>
	
		
		<div class="form-wrapper tab-content">
		<?php $incre_id = 1; foreach ($settings['contact_form_repeater'] as $item): ?>
		<?php if(!empty($item['cf7'])): ?>	
			<div 
			class="contact-form slope-cf7-<?php echo esc_attr($id.strval($incre_id)); ?> 
			tab-pane fade <?php echo esc_attr($incre_id == 1 ? 'active show': ''); ?>" 
			id="slope-cf7-id-<?php echo esc_attr($id.strval($incre_id)); ?>"
			role="tabpanel"
			aria-labelledby="slope-cf7-id-<?php echo esc_attr($id.strval($incre_id)); ?>-tab"
			>
                <?php echo do_shortcode('[contact-form-7 id="'.$item['cf7'].'"]'); ?>
           </div>	
		<?php endif; ?>
		<?php $incre_id++; endforeach; ?>
		</div>

		</div>
	
<?php
	
    }

    protected function get_contact_form_7_forms(){

	 	$args = array('post_type' => 'wpcf7_contact_form', 'posts_per_page' => -1);

	    $catlist=[];
	    
	    if( $categories = get_posts($args)){
	    	foreach ( $categories as $category ) {
	    		(int)$catlist[$category->ID] = $category->post_title;
	    	}
	    }
	    else{
	        (int)$catlist['0'] = esc_html__('No contact From 7 form found', 'slope');
	    }
	  	return $catlist;
	}

}

