<?php

if (!defined('ABSPATH')) exit; // Exit if accessed directly


class ImageSlider extends \Elementor\Widget_Base{

  public function get_name(){
    return 'image_slider_slope';
  }

  public function get_title(){
    return __( 'Image Slider', 'slope' );
  }

  public function get_icon(){
    return 'fas fa-images';
  }

  public function get_categories(){
    return ['gfxpartner'];
  }

  protected function register_controls(){

    // image slides - start

    $this->start_controls_section(
      'image_slider_content',
      [
        'label' => __('Slides', 'slope'),
        'tab' => \Elementor\Controls_Manager::TAB_CONTENT
      ]
    );

    $repeater = new \Elementor\Repeater();

    $repeater->add_control(
        'image_slider_image',
        [
            'label' => __( 'Choose Image', 'slope' ),
            'type' => \Elementor\Controls_Manager::MEDIA,
            'default' => [
                'url' => \Elementor\Utils::get_placeholder_image_src(),
            ],
        ]
    );
    
    $this->add_control(
      'image_slider_repeater',
      [
        'label' => __( 'Image slides', 'slope' ),
        'type' => \Elementor\Controls_Manager::REPEATER,
        'fields' => $repeater->get_controls(),
        'default' => [
          [
            'image_slider_image' => '',
          ],
        ],
        'title_field' => __ ( 'Image','slope' ),
      ]
    );

    $this->end_controls_section();

    // image slides - end

    // slider options - start

    $this->start_controls_section(
      'image_slider_options_section',
      [
        'label' => __('Slider options', 'slope'),
        'tab' => \Elementor\Controls_Manager::TAB_CONTENT
      ]
    );

    $this->add_control(
      'image_slider_navigation',
      [
        'label' => __( 'Slider navigation', 'slope' ),
        'type' => \Elementor\Controls_Manager::SWITCHER,
        'label_on' => __( 'yes', 'slope' ),
        'label_off' => __( 'no', 'slope' ),
        'return_value' => 'yes',
        'default' => 'yes',
      ]
    );

    $this->add_control(
      'image_slider_prev_icon',
      [
        'label' => __('Navigation previous icon', 'slope'),
        'type' => \Elementor\Controls_Manager::ICONS,
        'condition' => ['image_slider_navigation' => 'yes']
      ]
    );

    $this->add_control(
      'image_slider_next_icon',
      [
        'label' => __('Navigation next icon', 'slope'),
        'type' => \Elementor\Controls_Manager::ICONS,
        'condition' => ['image_slider_navigation' => 'yes']
      ]
    );
    
    $this->add_control(
      'image_slider_autoplay',
      [
        'label' => __( 'Slider autoplay', 'slope' ),
        'type' => \Elementor\Controls_Manager::SWITCHER,
        'label_on' => __( 'yes', 'slope' ),
        'label_off' => __( 'no', 'slope' ),
        'return_value' => 'yes',
        'default' => 'yes',
      ]
    );

    $this->add_control(
      'image_slider_autoplay_delay',
      [
        'label' => __( 'Delay', 'slope' ),
        'description' => __('1000 represents 1 second', 'slope'),
        'type' => \Elementor\Controls_Manager::NUMBER,
        'min' => 0,
        'max' => 60000,
        'step' => 500,
        'default' => 2000
      ]
    );

    $this->add_control(
      'image_slider_speed',
      [
        'label' => __( 'Speed', 'slope' ),
        'description' => __('1000 represents 1 second', 'slope'),
        'type' => \Elementor\Controls_Manager::NUMBER,
        'min' => 0,
        'max' => 60000,
        'step' => 500,
        'default' => 2000
      ]
    );

    $this->add_control(
      'image_slider_loop',
      [
        'label' => __( 'Slider loop', 'slope' ),
        'type' => \Elementor\Controls_Manager::SWITCHER,
        'label_on' => __( 'yes', 'slope' ),
        'label_off' => __( 'no', 'slope' ),
        'return_value' => 'yes',
        'default' => 'yes',
      ]
    );

    $this->end_controls_section();

    // slider options - end

    // image style - start

    $this->start_controls_section(
        'image_slider_style',
        [
          'label' => __('Image', 'slope'),
          'tab' => \Elementor\Controls_Manager::TAB_STYLE
        ]
    );
  
    $this->add_group_control(
      \Elementor\Group_Control_Image_Size::get_type(),
      [
          'name' => 'thumbnail', // // Usage: `{name}_size` and `{name}_custom_dimension`, in this case `thumbnail_size` and `thumbnail_custom_dimension`.
          // 'exclude' => [ 'custom' ],
          'include' => [],
          'default' => 'large',
      ]
    );

    $this->add_responsive_control('image_slider_align',
      [
          'label'         => __( 'Alignment', 'slope' ),
          'type'          => \Elementor\Controls_Manager::CHOOSE,
          'options'       => [
              'left'      => [
                  'title'=> __( 'Left', 'slope' ),
                  'icon' => 'fa fa-align-left',
              ],
              'center'    => [
                  'title'=> __( 'Center', 'slope' ),
                  'icon' => 'fa fa-align-center',
              ],
              'right'     => [
                  'title'=> __( 'Right', 'slope' ),
                  'icon' => 'fa fa-align-right',
              ],
          ],
          'default'       => 'center',
          'selectors'     => [
              '{{WRAPPER}} .image-slider .swiper-slide' => 'text-align: {{VALUE}};',
          ],
      ]
    );

    $this->end_controls_section();

    // image style - end

    // container style - start

    $this->start_controls_section(
      'single_image_slider_container',
      [
        'label' => __('Container', 'slope'),
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );
  
    $this->add_responsive_control(
      'single_image_slider_container_width',
      [
        'label' => __( 'Width', 'slope' ),
        'type' => \Elementor\Controls_Manager::SLIDER,
        'size_units' => [ 'px', '%' ],
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 2000,
            'step' => 1,
          ],
          '%' => [
            'min' => 0,
            'max' => 300,
          ],
        ],
        'selectors' => [
          '{{WRAPPER}} .single-image' => 'width: {{SIZE}}{{UNIT}} !important;',
        ],
      ]
    );
  
    $this->add_responsive_control(
      'single_image_slider_container_height',
      [
        'label' => __( 'Height', 'slope' ),
        'type' => \Elementor\Controls_Manager::SLIDER,
        'size_units' => [ 'px', '%' ],
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 2000,
            'step' => 1,
          ],
          '%' => [
            'min' => 0,
            'max' => 300,
          ],
        ],
        'selectors' => [
          '{{WRAPPER}} .single-image' => 'height: {{SIZE}}{{UNIT}} !important;',
        ],
      ]
    );
  
    $this->add_responsive_control(
      'single_image_slider_fit',
      [
        'label' => __( 'Object fit', 'slope' ),
        'type' => \Elementor\Controls_Manager::SELECT,
        'options' => [
          'object-fit: initial; width: initial; height: initial;' => __( 'Initial', 'slope' ),
          'object-fit: cover; width: 100%; height: 100%;' => __( 'Cover', 'slope' ),
          'object-fit: contain; width: auto; height: auto;' => __( 'Contain', 'slope' ),
        ],
        'toggle' => true,
        'selectors' => [
          '{{WRAPPER}} .single-image img' => '{{VALUE}}',
        ],
      ]
    );
  
    $this->add_responsive_control(
      'single_image_slider_transform_alignment',
      [
        'label' => __( 'Image alignment', 'slope' ),
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => [ 'px', '%', 'em' ],
        'allowed_dimensions' => [ 'top', 'left' ],
  
        'selectors' => [
          '{{WRAPPER}} .single-image img' => 'transform: translate({{LEFT}}{{UNIT}} , {{TOP}}{{UNIT}});',        
        ],
      ]
    );
  
  
    $this->end_controls_section();

    // container style - end
  
  }
  

  protected function render(){
    $settings = $this->get_settings_for_display();
    $id = $this->get_id();

    // options for the slider
    $options = [
      'loop' => $settings['image_slider_loop'] ? true : false,
      'speed' =>  $settings['image_slider_speed'],
      'slidesPerView' => 1,
      'spaceBetween' => 0,
      'resizeObserver' => true
    ];

    // slider autoplay
    if ( $settings['image_slider_autoplay'] == 'yes' ) {
      $delay_arr = ['autoplay' => [
        'delay' => $settings['image_slider_autoplay_delay'],
        'disableOnInteraction' => false
      ]];
      $options = array_merge($options, $delay_arr);
    }

    // slider navigation
    if ($settings['image_slider_navigation'] == 'yes') {
      $navigation = [
        'navigation' => [
        'nextEl' => '.slider--nav-'.$id.' .slider--nav-next',
        'prevEl' => '.slider--nav-'.$id.' .slider--nav-prev',
        ]
      ];
      $options = array_merge($options, $navigation);
    }

    ?>
    <div class="image-slider">
      <!-- slider - start -->
      <div class="swiper-container slider-<?php echo esc_attr($id); ?>">
        <div class="swiper-wrapper">

          <?php foreach ($settings['image_slider_repeater'] as $item): ?>
            <div class="swiper-slide">
              <div class="single-image">
                <?php echo \Elementor\Group_Control_Image_Size::get_attachment_image_html( $item, 'thumbnail', 'image_slider_image' ); ?>
              </div>
            </div>
          <?php endforeach; ?>

        </div>
      </div>
      <!-- slider - end -->
      <!-- slider navigation - start -->
      <div class="slider--nav slider--nav-<?php echo esc_attr($id); ?>">
        <div class="slider--nav-prev">
          <?php \Elementor\Icons_Manager::render_icon( $settings['image_slider_prev_icon'], [ 'aria-hidden' => 'true' ] ); ?>
        </div>
        <div class="slider--nav-next">
          <?php \Elementor\Icons_Manager::render_icon( $settings['image_slider_next_icon'], [ 'aria-hidden' => 'true' ] ); ?>
        </div>
      </div>
      <!-- slider navigation - end -->
    </div>
    <?php slope_render_script($id, $options);
  }
}
