<?php

if (!defined('ABSPATH')) exit; // Exit if accessed directly


class Projects extends \Elementor\Widget_Base{

  public function get_name(){
    return 'projects_slope';
  }

  public function get_title(){
    return __( 'Projects', 'slope' );
  }

  public function get_icon(){
    return 'fas fa-archway';
  }

  public function get_categories(){
    return ['gfxpartner'];
  }

  protected function register_controls(){

    // project options - start

    $this->start_controls_section(
      'project_section',
      [
          'label' => __( 'Project Options', 'slope' ),
          'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
      ]
    );

    $this->add_control(
      'project_layout',
      [
        'label' => __( 'Layout', 'slope' ),
        'type' => \Elementor\Controls_Manager::SELECT,
        'default' => 'layout_1',
        'options' => [
          'project-list-1'  => __( 'Layout 1', 'slope' ),
          'project-list-2' => __( 'Layout 2', 'slope' ),
        ],
      ]
    );

    $this->add_control(
      'show_load_more',
      [
        'label' => __( 'Show load more button', 'slope' ),
        'type' => \Elementor\Controls_Manager::SWITCHER,
        'label_on' => __( 'Yes', 'slope' ),
        'label_off' => __( 'No', 'slope' ),
        'return_value' => 'yes',
        'default' => 'yes',
      ]
    );

    $this->add_control(
      'slope_projects_number',
      [
        'label' => __( 'Posts per page', 'slope' ),
        'type'          => \Elementor\Controls_Manager::NUMBER,
        'min'			=> -1,
        'default' => 4
      ]
    );

    $this->add_control(
      'slope_projects_order',
      [
        'label' => __( 'Order posts', 'slope' ),
        'type' => \Elementor\Controls_Manager::SELECT,
        'options' => [
          'DESC' => 'descending',
          'ASC' => 'ascending',
        ],
        'default' => 'DESC',
      ]
    );

    $this->add_control(
      'slope_projects_sort',
      [
        'label' => __( 'Sorting posts by', 'slope' ),
        'type' => \Elementor\Controls_Manager::SELECT,
        'options' => [
          'date' => 'date',
          'modified' => 'last modified date',
          'rand' => 'Random',
          'title' => 'title',
          'comment_count' => 'number of comments',
        ],
        'default' => 'date',
      ]
    );
    
    $this->end_controls_section();

    // project options - end

    // title style - start

    $this->start_controls_section(
      'project_style_title_section',
      [
        'label' => __('Title', 'slope'),
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );

    $this->add_group_control(
      \Elementor\Group_Control_Typography::get_type(),
      [
          'name' => 'project_title_format',
          'label' => __('Typography', 'slope'),
          'selector' => '{{WRAPPER}} .project-list-single--content h2',
      ]
    );

    $this->add_control(
      'project_title_color',
      [
        'label' => __('Color', 'slope'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .project-list-single--content h2' => 'color : {{VALUE}}',
        ],
      ]
    );

    $this->end_controls_section();

    // title style - end

    // detail style - start

    $this->start_controls_section(
      'project_style_details_section',
      [
        'label' => __('Details', 'slope'),
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );

    $this->add_group_control(
      \Elementor\Group_Control_Typography::get_type(),
      [
          'name' => 'project_detail_format',
          'label' => __('Typography', 'slope'),
          'selector' => '{{WRAPPER}} .project-list-single--content .project-single-service h3,
          {{WRAPPER}} .project-list-single--content .project-single-client h3',
      ]
    );

    $this->add_control(
      'project_detail_color',
      [
        'label' => __('Color', 'slope'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .project-list-single--content .project-single-service h3,
          {{WRAPPER}} .project-list-single--content .project-single-client h3' => 'color : {{VALUE}}',
        ],
      ]
    );

    $this->end_controls_section();

    // detail style - end

    // icon style - start

    $this->start_controls_section(
      'project_style_icon_section',
      [
        'label' => __('Icon', 'slope'),
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );

    $this->add_control(
      'project_icon_color',
      [
        'label' => __('Color', 'slope'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .project-list-single--content .project-single-button--inner i' => 'color : {{VALUE}}',
        ],
      ]
    );

    $this->add_control(
      'project_icon_bg_outer_color',
      [
        'label' => __('Outer color', 'slope'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .project-list-single--content .project-single-button' => 'background-color : {{VALUE}}',
        ],
      ]
    );

    $this->add_control(
      'project_icon_bg_inner_color',
      [
        'label' => __('Inner color', 'slope'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .project-list-single--content .project-single-button--inner' => 'background-color : {{VALUE}}',
        ],
      ]
    );

    $this->end_controls_section();

    // icon style - end

    // background style - start

    $this->start_controls_section(
      'project_content_miscellaneous_style',
      [
        'label' => __('Miscellaneous', 'slope'),
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );

    $this->add_control(
      'project_content_bg_color_layout_1',
      [
        'label' => __('Color', 'slope'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .project-list-single--content' => 'background-color : {{VALUE}}',
        ],
        'condition' => ['project_layout' => 'layout_1']
      ]
    );

    $this->add_control(
      'project_content_bg_color_layout_2',
      [
        'label' => __('Color', 'slope'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .project-list.project-list-2 .project-list-single .project-list-single--content' => 'background-color : {{VALUE}}',
        ],
        'condition' => ['project_layout' => 'layout_2']
      ]
    );

    $this->add_responsive_control(
      'project_content_width_style',
      [
        'label' => __( 'Content width', 'slope' ),
        'type' => \Elementor\Controls_Manager::SLIDER,
        'size_units' => [ 'px', '%' ],
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 2000,
            'step' => 1,
          ],
          '%' => [
            'min' => 0,
            'max' => 100,
          ],
        ],
        'selectors' => [
          '{{WRAPPER}} .project-list-single--content-inner' => 'width: {{SIZE}}{{UNIT}} !important;',
        ],
      ]
    );

    $this->end_controls_section();

    // background style - end

    // load more button style - start

    $this->start_controls_section(
      'button_load_more_style',
      [
        'label' => __('Load more button', 'slope'),
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );

    $this->add_responsive_control('load_more_align',
      [
          'label'         => __( 'Alignment', 'slope' ),
          'type'          => \Elementor\Controls_Manager::CHOOSE,
          'options'       => [
              'left'      => [
                  'title'=> __( 'Left', 'slope' ),
                  'icon' => 'fa fa-align-left',
              ],
              'center'    => [
                  'title'=> __( 'Center', 'slope' ),
                  'icon' => 'fa fa-align-center',
              ],
              'right'     => [
                  'title'=> __( 'Right', 'slope' ),
                  'icon' => 'fa fa-align-right',
              ],
          ],
          'default'       => 'center',
          'selectors'     => [
              '{{WRAPPER}} .load-more' => 'text-align: {{VALUE}};',
          ],
      ]
    );

    $this->add_control(
      'button_background_bg',
      [
        'label' => __('Box background color', 'slope'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .load-more' => 'background-color : {{VALUE}}'
        ]
        
      ]
    );

    $this->add_group_control(
      \Elementor\Group_Control_Typography::get_type(),
      [
          'name' => 'button_text',
          'label' => __('Text', 'slope'),
          'selector' => '{{WRAPPER}} .button',
      ]
    );

    $this->start_controls_tabs( 'button_tabs' );

    $this->start_controls_tab(
      'button_normal',
      [
          'label' => __( 'Normal', 'slope' ),
      ]
    );

    $this->add_control(
      'button_text_color',
      [
        'label' => __('Text color', 'slope'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .button:hover' => 'color : {{VALUE}}'
        ]
      ]
    );

    $this->add_control(
    'button_bg_color',
    [
      'label' => __('Background color', 'slope'),
      'type' => \Elementor\Controls_Manager::COLOR,
      'selectors' => [
        '{{WRAPPER}} .button::before' => 'background-color : {{VALUE}}'
      ] 
    ]
    );


    $this->end_controls_tab();

    $this->start_controls_tab(
      'button_hover',
      [
          'label' => __( 'Hover', 'slope' ),
      ]
    );

    $this->add_control(
      'button_text_color_hover',
      [
        'label' => __('Text hover color', 'slope'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .button:hover' => 'color : {{VALUE}}'
        ]   
      ]
    );

    $this->add_control(
    'button_bg_color_hover',
    [
      'label' => __('Background color', 'slope'),
      'type' => \Elementor\Controls_Manager::COLOR,
      'selectors' => [
        '{{WRAPPER}} .button::after' => 'background-color : {{VALUE}}'
      ]
    ]
    );

    $this->end_controls_tab();

    $this->end_controls_tabs();  

    $this->end_controls_section();

    // load more button style - end
  
  }
  

  protected function render(){
    $settings = $this->get_settings_for_display();
    $id = $this->get_id();

    $paged = (get_query_var('paged')) ? get_query_var('paged') : 1; 
    $args = array(
      'post_type' => 'project',
      'posts_per_page' => esc_attr($settings['slope_projects_number']),
      'orderby'     => esc_attr($settings['slope_projects_sort']),
      'order'       => esc_attr($settings['slope_projects_order']),      
      'paged' => $paged,
      'post_status'    => 'publish'
    );
      
    $query = new \WP_Query( $args );

    $class_list = array('project-list', 'project-list-'.$id, $settings['project_layout']);
    $max = wp_count_posts('project')->publish;

    if( $settings['show_load_more'] == 'yes' ) {
      array_push($class_list, 'load-more-enabled');
    }
    
  ?>
    <div 
    class="<?php echo esc_attr( implode( ' ', $class_list) ); ?>"
    data-max="<?php echo esc_attr($max); ?>"
    >
      <?php 
        if ( $query->have_posts() ) {
          while ( $query->have_posts() ) {
            $query->the_post();
            get_template_part('/inc/template/part', 'project'); 
          }
          wp_reset_postdata(); 
        }
      ?>             
    </div>
    <?php if( $settings['show_load_more'] == 'yes' ): ?>
      <div class="load-more load-more-<?php echo esc_attr($id); ?> <?php echo esc_attr( $settings['project_layout'] ); ?>">
        <a class="button">
          <span>Load More</span>
        </a>
      </div>      
    <?php 
      slope_project_load_script( $id, $settings['slope_projects_number'] );
      endif;
    ?>
    <?php
  }
  }

