<?php

if (!defined('ABSPATH')) exit; // Exit if accessed directly


class Services extends \Elementor\Widget_Base{

  public function get_name(){
    return 'image_box_slope';
  }

  public function get_title(){
    return __( 'Services', 'slope' );
  }

  public function get_icon(){
    return 'fas fa-cube';
  }

  public function get_categories(){
    return ['gfxpartner'];
  }

  protected function register_controls(){

    // service content - start

    $this->start_controls_section(
      'service_content_section',
      [
        'label' => __('Content', 'slope'),
        'tab' => \Elementor\Controls_Manager::TAB_CONTENT
      ]
    );

    $this->add_control(
      'service_layout',      
      [
        'label' => __( 'Layout', 'slope' ),
        'type' => \Elementor\Controls_Manager::SELECT,
        'default' => 'with_images',
        'options' => [
            'service-image'  => __( 'Layout 1', 'slope' ),
            'service-withoutimage' => __( 'Layout 2', 'slope' ),
        ],
        ]
    );

    $this->add_control(
      'slope_service_number',
      [
      'label' => __( 'Posts per page', 'slope' ),
      'type'          => \Elementor\Controls_Manager::NUMBER,
      'min'			=> -1,
      'default' => 2
      ]
    );

    $this->add_control(
    'slope_service_order',
    [
      'label' => __( 'Order posts', 'slope' ),
      'type' => \Elementor\Controls_Manager::SELECT,
      'options' => [
          'DESC' => 'descending',
          'ASC' => 'ascending',
      ],
      'default' => 'DESC',
    ]
    );

    $this->add_control(
    'slope_service_sort',
    [
      'label' => __( 'Sorting posts by', 'slope' ),
      'type' => \Elementor\Controls_Manager::SELECT,
      'options' => [
          'date' => 'date',
          'modified' => 'last modified date',
          'rand' => 'Random',
          'title' => 'title',
          'comment_count' => 'number of comments',
      ],
      'default' => 'date',
    ]
    );

    $this->end_controls_section();

    // service content - end

    // layout 1 heading - start

    $this->start_controls_section(
      'service_layout_1_heading_style',
      [
        'label' => __('Heading', 'slope'),
        'tab' => \Elementor\Controls_Manager::TAB_STYLE,
        'condition' => ['service_layout' => 'service-image']
      ]
    );

    $this->add_group_control(
      \Elementor\Group_Control_Typography::get_type(),
      [
          'name' => 'ser_img_heading',
          'label' => __('Typography', 'slope'),
          'selector' => '{{WRAPPER}} .service--box--image .service--box--content h4',
      ]
    );

    $this->add_control(
      'ser_img_heading_color',
      [
        'label' => __('Color', 'slope'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .service--box--image .service--box--content h4' => 'color : {{VALUE}}',
        ],
      ]
    );

    $this->end_controls_section();

    // layout 1 heading - end

    // layout 1 excerpt - start

    $this->start_controls_section(
      'service_layout_1_excerpt_style',
      [
        'label' => __('Excerpt', 'slope'),
        'tab' => \Elementor\Controls_Manager::TAB_STYLE,
        'condition' => ['service_layout' => 'service-image']
      ]
    );

    $this->add_group_control(
      \Elementor\Group_Control_Typography::get_type(),
      [
          'name' => 'ser_img_excerpt',
          'label' => __('Typography', 'slope'),
          'selector' => '{{WRAPPER}} .service--box--image .service--box--content .paragraph',
      ]
    );

    $this->add_control(
      'ser_img_exercept_color',
      [
        'label' => __('Color', 'slope'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .service--box--image .service--box--content .paragraph' => 'color : {{VALUE}}',
        ],
      ]
    );

    $this->end_controls_section();

    // layout 1 excerpt - end

    // layout 1 icon - start

    $this->start_controls_section(
      'service_layout_1_icon_style',
      [
        'label' => __('Icon', 'slope'),
        'tab' => \Elementor\Controls_Manager::TAB_STYLE,
        'condition' => ['service_layout' => 'service-image']
      ]
    );

    $this->start_controls_tabs( 'service_image_tabs' );
    
    $this->start_controls_tab(
        'service_image_normal',
        [
            'label' => __( 'Normal', 'slope' ),
        ]
    );

    $this->add_control(
      'ser_img_text_color',
      [
        'label' => __('Color', 'slope'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .service--box--image i' => 'color : {{VALUE}}',
          '{{WRAPPER}} .service--box--image svg path' => 'fill : {{VALUE}}'
        ],
        'default' => '#000000'
      ]
    );

    $this->add_control(
      'ser_img_icon_bg_color',
      [
        'label' => __('Background color', 'slope'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .service--box--image .icon' => 'background-color : {{VALUE}}'
        ],
        'default' => '#00f6ff'
      ]
    );


    $this->end_controls_tab();

    $this->start_controls_tab(
        'service_image_hover',
        [
            'label' => __( 'Hover', 'slope' ),
        ]
    );

    $this->add_control(
      'ser_img_text_color_hover',
      [
        'label' => __('Color', 'slope'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'default' => '#FFFFFF'
      ]
    );

    $this->add_control(
      'ser_img_icon_bg_color_hover',
      [
        'label' => __('Background color', 'slope'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'default' => 'rgba(0,246,255,.6)'
      ]
    );

    $this->end_controls_tab();

    $this->end_controls_tabs();

    $this->end_controls_section();

    // layout 1 icon - end

    // layout 1 miscellaneous - start

    $this->start_controls_section(
      'service_layout_1_misc_style',
      [
        'label' => __('Miscellaneous', 'slope'),
        'tab' => \Elementor\Controls_Manager::TAB_STYLE,
        'condition' => ['service_layout' => 'service-image']
      ]
    );

    $this->add_control(
      'ser_img_content_bg',
      [
        'label' => __('Background color', 'slope'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .service--box > a' => 'background-color : {{VALUE}}',
        ],
      ]
    );

    $this->end_controls_section();

    // layout 1 miscellaneous - end

    $this->start_controls_section(
        'service_layout_2_style',
        [
          'label' => __('Style state', 'slope'),
          'tab' => \Elementor\Controls_Manager::TAB_STYLE,
          'condition' => ['service_layout' => 'service-withoutimage']
        ]
    );

    $this->start_controls_tabs( 'service_no_image_tabs' );
    
    $this->start_controls_tab(
        'service_no_image_normal',
        [
            'label' => __( 'Normal', 'slope' ),
        ]
    );

    $this->add_control(
      'ser_no_img_text_color',
      [
        'label' => __('Text color', 'slope'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .service--box-icon .text h4' => 'color : {{VALUE}}',
          '{{WRAPPER}} .service--box-icon svg path' => 'fill : {{VALUE}}'
        ],
        'default' => '#000000'
      ]
    );

    $this->add_control(
      'ser_no_img_border_color',
      [
        'label' => __('Border color', 'slope'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .service--box-icon' => 'border-color : {{VALUE}}'
        ],
        'default' => '00f6ff'
      ]
    );


    $this->add_control(
      'ser_no_img_bg_color',
      [
        'label' => __('Background color', 'slope'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .service--box-icon' => 'background-color : {{VALUE}}'
        ],
        'default' => '#fffff'
      ]
    );

    $this->end_controls_tab();

    $this->start_controls_tab(
        'service_no_image_hover',
        [
            'label' => __( 'Hover', 'slope' ),
        ]
    );

    $this->add_control(
      'ser_no_img_text_color_hover',
      [
        'label' => __('Text color', 'slope'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'default' => '#FFFFFF'
      ]
    );

    $this->add_control(
      'ser_no_img_border_color_hover',
      [
        'label' => __('Border color', 'slope'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'default' => '00f6ff'
      ]
    );

    $this->add_control(
      'ser_no_img_bg_color_hover',
      [
        'label' => __('Background color', 'slope'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'default' => '#00f6ff'
      ]
    );

    $this->end_controls_tab();

    $this->end_controls_tabs();
  
    $this->end_controls_section();
  
  }
  

  protected function render(){
    $settings = $this->get_settings_for_display();
    $id = $this->get_id();
    global $wp_query; global $post;
    $paged = (get_query_var('paged')) ? get_query_var('paged') : 1; 
    $args = array(
        'posts_per_page' => esc_attr($settings['slope_service_number']),
        'orderby'     => esc_attr($settings['slope_service_sort']),
        'order'       => esc_attr($settings['slope_service_order']),      
        'post_type' => esc_attr('service'),
        'paged' => $paged,
        'post_status'    => 'publish'
      );
      
      $query = new \WP_Query( $args );
    ?>
      <div class="service-section <?php echo esc_attr( $settings['service_layout'] ); ?>">
        <?php if ( $settings['service_layout'] == 'service-withoutimage' ): ?>
        <div class="container">
          <div class="row">
        <?php endif; // display container condition ?>
        <?php
          if ( $query->have_posts() ) {
            while( $query->have_posts() ) {
              $query->the_post();
              if ( $settings['service_layout'] == 'service-withoutimage' ) {
              ?>
                <div class="col-lg-4">
                  <?php 
                    get_template_part( 
                      'inc/template/part', 
                      'service-noimage'
                    );
                  ?>
                </div>
              <?php
              } else {
                get_template_part( 
                  'inc/template/part', 
                  'service-image'
                );
              } // service style condition
            } // while
          } // if
        ?>
        <?php if ( $settings['service_layout'] == 'service-withoutimage' ): ?>
          </div>
        </div>
        <?php 
            slope_service_noimage_anim($settings);
          else:
            slope_service_image_anim($settings);
          endif; // display container condition
        ?>
        <?php
        if
          (
            \Elementor\Plugin::$instance->editor->is_edit_mode() || 
            \Elementor\Plugin::$instance->preview->is_preview_mode()
          )
          {
            slope_svg_script();
          }
        ?>
      </div>

      <?php if ($settings['service_layout'] == 'with_images'): ?>
      <div class="service-section service-image">
       <?php if ($query->have_posts()): while($query->have_posts()):  $query->the_post() ?>
        <div class="service--box service--box--<?php echo get_the_ID(); ?>">
            <?php if (has_post_thumbnail()): ?>
            <div class="service--box--image">
                <a href="<?php the_permalink(); ?>">
                <?php the_post_thumbnail('service-thumbnail-size'); ?>
                <?php 
                    $icon_method = '';
                    if (function_exists('get_field')) {
                      $icon_method = get_field('icon_method');
                      $icon_name = get_field('service_fontawesome_icon');    
                      $icon_image = wp_get_attachment_image(get_field('upload_icon'), '', true, array( "class" => "svg" )); 
                    }
                ?>           
                <div class="icon">
                  <?php if ($icon_method == 'Font awesome icon'): ?>
                  <i class="<?php echo esc_attr($icon_name); ?>"></i>
                  <?php endif; ?>
                  <?php if ($icon_method == 'Upload SVG'): ?>
                  <?php echo wp_kses_post($icon_image); ?>
                  <?php endif; ?>
                </div>
                </a>
            </div>
            <?php endif; ?>
            <a href="<?php the_permalink(); ?>">
            <div class="service--box--content">                
                <h4><?php the_title(); ?></h4>
                <?php the_excerpt(); ?>
            </div>
            </a>
       </div>
       <?php endwhile; ?>
       
       <?php endif; ?>
       </div>
      <?php endif; ?>
    <?php
  }
}
