<?php

if (!defined('ABSPATH')) exit; // Exit if accessed directly


class SingleImage extends \Elementor\Widget_Base{

  public function get_name(){
    return 'singleImage_slope';
  }

  public function get_title(){
    return __( 'Single Image', 'slope' );
  }

  public function get_icon(){
    return 'fas fa-image';
  }

  public function get_categories(){
    return ['gfxpartner'];
  }

  protected function register_controls(){

    $this->start_controls_section(
      'single_image_content_section',
      [
        'label' => __('Content', 'slope'),
        'tab' => \Elementor\Controls_Manager::TAB_CONTENT
      ]
    );

    $this->add_control(
        'single_Image_image',
        [
            'label' => __( 'Choose Image', 'slope' ),
            'type' => \Elementor\Controls_Manager::MEDIA,
            'default' => [
                'url' => \Elementor\Utils::get_placeholder_image_src(),
            ],
        ]
    );

    $this->end_controls_section();

    $this->start_controls_section(
      'single_image_styles_section',
      [
        'label' => __('Style', 'slope'),
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );


    $this->add_group_control(
        \Elementor\Group_Control_Image_Size::get_type(),
        [
            'name' => 'image_prop', // // Usage: `{name}_size` and `{name}_custom_dimension`, in this case `image_prop_size` and `image_prop_custom_dimension`.
            'default' => 'full',
        ]
    );

    $this->add_control(
      'single_image_width',
      [
        'label' => __( 'Full width image', 'slope' ),
        'type' => \Elementor\Controls_Manager::SWITCHER,
        'label_on' => __( 'Yes', 'slope' ),
        'label_off' => __( 'No', 'slope' ),
        'return_value' => 'yes',
        'default' => 'no',
      ]
    );

    $this->add_responsive_control('single_image_align',
            [
                'label'         => __( 'Alignment', 'slope' ),
                'type'          => \Elementor\Controls_Manager::CHOOSE,
                'options'       => [
                    'left'      => [
                        'title'=> __( 'Left', 'slope' ),
                        'icon' => 'fa fa-align-left',
                    ],
                    'center'    => [
                        'title'=> __( 'Center', 'slope' ),
                        'icon' => 'fa fa-align-center',
                    ],
                    'right'     => [
                        'title'=> __( 'Right', 'slope' ),
                        'icon' => 'fa fa-align-right',
                    ],
                ],
                'default'       => 'center',
                'selectors'     => [
                    '{{WRAPPER}} .single-image' => 'text-align: {{VALUE}};',
                ],
            ]
    );

  $this->end_controls_section();

  $this->start_controls_section(
    'single_image_container',
    [
      'label' => __('Container', 'slope'),
      'tab' => \Elementor\Controls_Manager::TAB_STYLE
    ]
  );

  $this->add_responsive_control(
    'single_image_container_width',
    [
      'label' => __( 'Width', 'slope' ),
      'type' => \Elementor\Controls_Manager::SLIDER,
      'size_units' => [ 'px', '%' ],
      'range' => [
        'px' => [
          'min' => 0,
          'max' => 2000,
          'step' => 1,
        ],
        '%' => [
          'min' => 0,
          'max' => 300,
        ],
      ],
      'selectors' => [
        '{{WRAPPER}} .single-image' => 'width: {{SIZE}}{{UNIT}};',
      ],
    ]
  );

  $this->add_responsive_control(
    'single_image_container_height',
    [
      'label' => __( 'Height', 'slope' ),
      'type' => \Elementor\Controls_Manager::SLIDER,
      'size_units' => [ 'px', '%' ],
      'range' => [
        'px' => [
          'min' => 0,
          'max' => 2000,
          'step' => 1,
        ],
        '%' => [
          'min' => 0,
          'max' => 300,
        ],
      ],
      'selectors' => [
        '{{WRAPPER}} .single-image' => 'height: {{SIZE}}{{UNIT}};',
      ],
    ]
  );

  $this->add_responsive_control(
    'single_image_fit',
    [
      'label' => __( 'Object fit', 'slope' ),
      'type' => \Elementor\Controls_Manager::SELECT,
      'options' => [
        'object-fit: initial; width: initial; height: initial;' => __( 'Initial', 'slope' ),
        'object-fit: cover; width: 100%; height: 100%;' => __( 'Cover', 'slope' ),
        'object-fit: contain; width: auto; height: auto;' => __( 'Contain', 'slope' ),
      ],
      'toggle' => true,
      'selectors' => [
        '{{WRAPPER}} .single-image img' => '{{VALUE}}',
      ],
    ]
  );

  $this->add_responsive_control(
    'single_image_transform_alignment',
    [
      'label' => __( 'Image alignment', 'slope' ),
      'type' => \Elementor\Controls_Manager::DIMENSIONS,
      'size_units' => [ 'px', '%', 'em' ],
      'allowed_dimensions' => [ 'top', 'left' ],

      'selectors' => [
        '{{WRAPPER}} .single-image img' => 'transform: translate({{LEFT}}{{UNIT}} , {{TOP}}{{UNIT}});',        
      ],
    ]
  );


  $this->end_controls_section();



  }
  

  protected function render(){
    $settings = $this->get_settings_for_display();
    $alt = get_post_meta( $settings['single_Image_image']['id'], '_wp_attachment_image_alt', TRUE);
    ?>
    <div class="single-image <?php echo esc_attr($settings['single_image_width'] ? 'full-width' : ''); ?>">
      <img src="<?php echo esc_url( $settings['single_Image_image']['url'] ) ?>" alt="<?php echo esc_attr( $alt ); ?>">
    </div>
    <?php
  }

  protected function _content_template(){

    ?>
    <#
    var image = {
        id: settings.single_Image_image.id,
        url: settings.single_Image_image.url,
        size: settings.image_prop_size,
        dimension: settings.image_prop_custom_dimension,
        model: view.getEditModel()
    };
    var image_url = elementor.imagesManager.getImageUrl( image );
    #>
    <div class="single-image
    <# if (settings.single_image_width) { #>
    full-width
    <# } #>
    ">
        <img src="{{{image_url}}}" alt="image">
    </div>
    <?php
  }
}
