<?php 

    get_header();

    // determine the title of the page.
    $title = single_post_title('', false);
    if (empty($title)) {
        $title = esc_html__( 'News Feeds', 'slope' );
    } 

    // build query
    $paged = (get_query_var('paged')) ? get_query_var('paged') : 1;
    $query = new WP_Query(array(
        'post_type' => 'post',
        'post_status'=> 'publish',
        'paged' => $paged
    ));

    $display_sidebar =  is_active_sidebar('blog-sidebar');

    $content_column = $display_sidebar ? 'col-lg-8' : 'col-lg-12';

?>

<div class="container index-header">
    <div class="row">
        <div class="col-lg-8">
            <h1 class="page-title"><?php echo esc_html($title); ?></h1>
        </div>
    </div>
</div>

<div class="container sidebar-page blog-page <?php echo esc_html( $display_sidebar ? 'sidebar-displayed': '' ); ?>">
    <div class="row">
        <div class="<?php echo esc_html( $content_column ); ?> content-column right-sidebar">
            <div class="content-column-wrapper">
                <?php if ($query->have_posts()): ?>
                <div class="blog-list">
                    <div class="container">
                        <div class="blog-list-container">
                            <div class="row" >
                                <?php 
                                    while ($query->have_posts()): 
                                        $query->the_post();
                                        // get single post
                                        get_template_part('inc/template/part', 'post', array(
                                            'id' => get_the_ID(),
                                            'blog_layout' => $display_sidebar ? 'list-1' : 'grid-1'
                                        ));
                                    endwhile; 
                                    wp_reset_postdata();
                                ?>
                            </div>
                        </div>
                        <?php 
                            if ( !empty( get_previous_posts_link() ) || !empty( get_next_posts_link() ) ):
                        ?>
                        <div class="row">
                            <div class="col-lg-12">
                                <div class="pagination-container">
                                    <?php 
                                        $args =  array(
                                            'base'         => str_replace( 999999999, '%#%', esc_url( get_pagenum_link( 999999999 ) ) ),
                                            'total'        => $wp_query->max_num_pages,
                                            'current'      => max( 1, get_query_var( 'paged' ) ),
                                            'format'       => '?paged=%#%',
                                            'show_all'     => false,
                                            'type'         => 'list',
                                            'end_size'     => 2,
                                            'mid_size'     => 1,
                                            'prev_next'    => false,
                                            'add_args'     => false,
                                            'add_fragment' => '',
                                        ) ;
                                        echo paginate_links( $args ); 
                                    ?>
                                </div>
                            </div>
                        </div>
                        <?php endif; ?>
                    </div>
                </div>
                <?php else: ?>
                    <p class="paragraph"><?php echo esc_html__('There are no posts to display', 'slope') ?></p>
                <?php endif; ?>
            </div>
        </div>
        <?php if ( $display_sidebar ): ?>
        <div class="col-lg-4 sidebar-column">
            <div class="sidebar-column-wrapper">
                <?php get_sidebar('blog-sidebar'); ?>
            </div>
        </div>
        <?php endif; ?>
    </div>
</div>

<?php get_footer(); ?>